cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=2; plural=n > 1;
return plural;
},
  "language": "fr",
  "x-generator": "Weblate 4.6.2"
 },
 "$0 CPU configuration": [
  null,
  "$0 Configuration du CPU"
 ],
 "$0 Network": [
  "$0 Networks",
  "$0 Réseau",
  "$0 Réseaux"
 ],
 "$0 Storage pool": [
  "$0 Storage pools",
  "$0 Pool de stockage",
  "$0 Pools de stockage"
 ],
 "$0 day": [
  "$0 days",
  "$0 jour",
  "$0 jours"
 ],
 "$0 hour": [
  "$0 hours",
  "$0 heure",
  "$0 heures"
 ],
 "$0 is available for most operating systems. To install it, search for it in GNOME Software or run the following:": [
  null,
  "$0 est disponible pour la plupart des systèmes d’exploitation. Pour l’installer, recherchez-le dans le logiciel GNOME ou exécutez les opérations suivantes :"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0 n’est disponible dans aucun référentiel."
 ],
 "$0 memory adjustment": [
  null,
  "$0 ajustement de la mémoire"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 minute",
  "$0 minutes"
 ],
 "$0 month": [
  "$0 months",
  "$0 mois",
  "$0 mois"
 ],
 "$0 network": [
  null,
  "$0 réseau"
 ],
 "$0 vCPU": [
  "$0 vCPUs",
  "$0 vCPU",
  "$0 vCPUs"
 ],
 "$0 vCPU details": [
  null,
  "$0 détails vCPU"
 ],
 "$0 virtual network interface settings": [
  null,
  "$0 les paramètres de l'interface réseau virtuelle"
 ],
 "$0 week": [
  "$0 weeks",
  "$0 semaine",
  "$0 semaines"
 ],
 "$0 will be installed.": [
  null,
  "$0 sera installé."
 ],
 "$0 year": [
  "$0 years",
  "$0 an",
  "$0 ans"
 ],
 "1 day": [
  null,
  "1 jour"
 ],
 "1 hour": [
  null,
  "1 heure"
 ],
 "1 minute": [
  null,
  "1 minute"
 ],
 "1 week": [
  null,
  "1 semaine"
 ],
 "20 minutes": [
  null,
  "20 minutes"
 ],
 "40 minutes": [
  null,
  "40 minutes"
 ],
 "5 minutes": [
  null,
  "5 minutes"
 ],
 "6 hours": [
  null,
  "6 heures"
 ],
 "60 minutes": [
  null,
  "60 minutes"
 ],
 "Absent": [
  null,
  "Absent"
 ],
 "Access": [
  null,
  "Accès"
 ],
 "Activate": [
  null,
  "Activer"
 ],
 "Activate the storage pool to administer volumes": [
  null,
  "Activer le pool de stockage pour gérer les volumes"
 ],
 "Add": [
  null,
  "Ajouter"
 ],
 "Add disk": [
  null,
  "Ajouter un disque"
 ],
 "Add network interface": [
  null,
  "Ajouter une interface réseau"
 ],
 "Add virtual network interface": [
  null,
  "Ajouter une interface de réseau virtuel"
 ],
 "Additional": [
  null,
  "Additionnel"
 ],
 "Additional packages:": [
  null,
  "Paquets supplémentaires :"
 ],
 "Address": [
  null,
  "Adresse"
 ],
 "Address not within subnet": [
  null,
  "Adresse ne faisant pas partie du sous-réseau"
 ],
 "Advanced TCA": [
  null,
  "TCA avancé"
 ],
 "After deleting the snapshot, all its captured content will be lost.": [
  null,
  "Après la suppression de l'instantané, tout son contenu capturé sera perdu."
 ],
 "All": [
  null,
  "Tout"
 ],
 "All logs": [
  null,
  "Tous les journaux"
 ],
 "All-in-one": [
  null,
  "Tout en un"
 ],
 "Always attach": [
  null,
  "Toujours attacher"
 ],
 "Ansible": [
  null,
  "Ansible"
 ],
 "Ansible roles documentation": [
  null,
  "Documentation des rôles Ansible"
 ],
 "Apply": [
  null,
  "Appliquer"
 ],
 "Attaching it will make this disk shareable for every VM using it.": [
  null,
  "Le fait de l’attacher rendra ce disque partageable pour chaque VM qui l'utilise."
 ],
 "Automatic": [
  null,
  "Automatique"
 ],
 "Automatically start libvirt on boot": [
  null,
  "Lancement automatique de libvirt au démarrage"
 ],
 "Automatically using NTP": [
  null,
  "Utiliser automatiquement NTP"
 ],
 "Automatically using specific NTP servers": [
  null,
  "Utiliser automatiquement des serveurs NTP spécifiques"
 ],
 "Automation script": [
  null,
  "Script d'automation"
 ],
 "Autostart": [
  null,
  "Démarrage automatique"
 ],
 "Blade": [
  null,
  "Lame"
 ],
 "Blade enclosure": [
  null,
  "Boîtier en lame"
 ],
 "Blocked": [
  null,
  "Bloqué"
 ],
 "Boot order": [
  null,
  "Ordre d’amorçage"
 ],
 "Boot order settings could not be saved": [
  null,
  "Les paramètres d’ordre d’amorçage n’ont pas pu être enregistrés"
 ],
 "Bus": [
  null,
  "Bus"
 ],
 "Bus expansion chassis": [
  null,
  "Châssis d’extension de bus"
 ],
 "CD/DVD disc": [
  null,
  "Disque CD/DVD"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU configuration could not be saved": [
  null,
  "La configuration du CPU n'a pas pu être sauvegardée"
 ],
 "CPU type": [
  null,
  "Type de CPU"
 ],
 "Cache": [
  null,
  "Cache"
 ],
 "Cancel": [
  null,
  "Annuler"
 ],
 "Cannot schedule event in the past": [
  null,
  "Impossible de planifier un événement dans le passé"
 ],
 "Capacity": [
  null,
  "Capacité"
 ],
 "Change": [
  null,
  "Modification"
 ],
 "Change firmware": [
  null,
  "Changer de firmware"
 ],
 "Change system time": [
  null,
  "Modifier l’heure du système"
 ],
 "Changes will take effect after shutting down the VM": [
  null,
  "Ces modifications prendront effet après l'extinction de la VM"
 ],
 "Checking installed software": [
  null,
  "Vérification des logiciels installés"
 ],
 "Choose an operating system": [
  null,
  "Choisissez un système d’exploitation"
 ],
 "Clicking \"Launch remote viewer\" will download a .vv file and launch $0.": [
  null,
  "En cliquant sur \"Launch Remote Viewer\" (lancer l’afficheur à distance), vous téléchargerez un fichier .vv et le lancerez $0 ."
 ],
 "Clone": [
  null,
  "Clone"
 ],
 "Close": [
  null,
  "Fermer"
 ],
 "Cloud base image": [
  null,
  "Images Cloud Base"
 ],
 "Cloud init parameters": [
  null,
  ""
 ],
 "Compact PCI": [
  null,
  "PCI compact"
 ],
 "Confirm this action": [
  null,
  "Confirmer cette action"
 ],
 "Connect": [
  null,
  "Connecter"
 ],
 "Connect with any viewer application for following protocols": [
  null,
  "Connectez-vous à n'importe quelle application de visualisation pour les protocoles suivants"
 ],
 "Connecting to virtualization service": [
  null,
  "Connexion au service de virtualisation"
 ],
 "Connection": [
  null,
  "Connexion"
 ],
 "Console": [
  null,
  "Console"
 ],
 "Convertible": [
  null,
  "Convertible"
 ],
 "Copy": [
  null,
  "Copier"
 ],
 "Copy to clipboard": [
  null,
  "Copier dans le presse-papier"
 ],
 "Cores per socket": [
  null,
  "Cœurs par prise"
 ],
 "Could not revert to snapshot": [
  null,
  "N'a pas pu revenir à l'instantané"
 ],
 "Crashed": [
  null,
  "Planté"
 ],
 "Create": [
  null,
  "Créer"
 ],
 "Create VM": [
  null,
  "Créer une VM"
 ],
 "Create a clone VM based on $0": [
  null,
  "Créer un clone VM basé sur $0"
 ],
 "Create new": [
  null,
  "Créer Nouveau"
 ],
 "Create new task file with this content.": [
  null,
  "Créez un nouveau fichier de tâches avec ce contenu."
 ],
 "Create new virtual machine": [
  null,
  "Créer une nouvelle machine virtuelle"
 ],
 "Create new volume": [
  null,
  "Créer un nouveau volume"
 ],
 "Create snapshot": [
  null,
  "Créer Instantané"
 ],
 "Create storage pool": [
  null,
  "Création du pool de stockage"
 ],
 "Create storage volume": [
  null,
  "Création un volume de stockage"
 ],
 "Create virtual network": [
  null,
  "Créer un réseau virtuel"
 ],
 "Create volume": [
  null,
  "Créer un volume"
 ],
 "Creating VM": [
  null,
  "Création de la VM"
 ],
 "Creating VM installation": [
  null,
  "Création de l’installation de la VM"
 ],
 "Creation of VM $0 failed": [
  null,
  "La création de la VM $0 a échoué"
 ],
 "Creation time": [
  null,
  "Temps de création"
 ],
 "Ctrl+Alt+$0": [
  null,
  "Ctrl+Alt+$0"
 ],
 "Ctrl+Insert": [
  null,
  "Ctrl+Inser"
 ],
 "Current": [
  null,
  "Actuel"
 ],
 "Current allocation": [
  null,
  "Allocation actuelle"
 ],
 "Custom firmware: $0": [
  null,
  "Micrologiciel personnalisé : $0"
 ],
 "Custom path": [
  null,
  "Chemin personnalisé"
 ],
 "DHCP range": [
  null,
  "Plage DHCP"
 ],
 "Deactivate": [
  null,
  "Désactiver"
 ],
 "Delay": [
  null,
  "Retard"
 ],
 "Delete": [
  null,
  "Supprimer"
 ],
 "Delete $0 volume": [
  "Delete $0 volumes",
  "Supprimer le volume $0",
  "Supprimer les volumes $0"
 ],
 "Delete associated storage files:": [
  null,
  "Supprimer les fichiers de stockage associés :"
 ],
 "Delete content": [
  null,
  "Supprimer le contenu"
 ],
 "Delete storage pool $0": [
  null,
  "Supprimer le pool de stockage $0"
 ],
 "Delete the volumes inside this pool": [
  null,
  "Supprimer les volumes de ce pool"
 ],
 "Deleting an inactive storage pool will only undefine the pool. Its content will not be deleted.": [
  null,
  "Supprimer un pool de stockage inactif va seulement déprogrammer le pool. Son contenu ne sera pas supprimé."
 ],
 "Description": [
  null,
  "Description"
 ],
 "Desktop": [
  null,
  "Bureau"
 ],
 "Desktop viewer": [
  null,
  "Affichage de bureau"
 ],
 "Detach the disks using this pool from any VMs before attempting deletion.": [
  null,
  "Détachez les disques utilisant ce pool de toutes les VM avant de tenter la suppression."
 ],
 "Detachable": [
  null,
  "Détachable"
 ],
 "Device": [
  null,
  "Périphérique"
 ],
 "Devices": [
  null,
  "Périphériques"
 ],
 "Disconnect": [
  null,
  "Déconnecter"
 ],
 "Disconnected from serial console. Click the connect button.": [
  null,
  "Déconnecté de la console série. Cliquez sur le bouton Connecter."
 ],
 "Disk $0 fail to get detached from VM $1": [
  null,
  "Échec du détachement du disque $0 de la VM $1"
 ],
 "Disk failed to be attached": [
  null,
  "Le disque n’a pas pu être attaché"
 ],
 "Disk failed to be created": [
  null,
  "Le disque n’a pas pu être créé"
 ],
 "Disk image file": [
  null,
  "Fichier image disque"
 ],
 "Disk settings could not be saved": [
  null,
  "Les paramètres de configuration du disque n’ont pas pu être sauvegardés"
 ],
 "Disk-only snapshot": [
  null,
  "Instantané du disque uniquement"
 ],
 "Disks": [
  null,
  "Disques"
 ],
 "Docking station": [
  null,
  "Docking station"
 ],
 "Domain has crashed": [
  null,
  "Le domaine s'est planté"
 ],
 "Domain is blocked on resource": [
  null,
  "Le domaine est bloqué sur la ressource"
 ],
 "Download an OS": [
  null,
  "Télécharger un OS"
 ],
 "Downloading $0": [
  null,
  "Téléchargement $0"
 ],
 "Dual rank": [
  null,
  "Double rang"
 ],
 "Dying": [
  null,
  "Sur le point ce cesser toute activité"
 ],
 "Edit": [
  null,
  "Modifier"
 ],
 "Edit $0 attributes": [
  null,
  "Modifier les attributs de $0"
 ],
 "Embedded PC": [
  null,
  "PC intégré"
 ],
 "Emulated machine": [
  null,
  "Machine émulée"
 ],
 "End": [
  null,
  "Fin"
 ],
 "End should not be empty": [
  null,
  "L’extrémité ne doit pas être vide"
 ],
 "Error message": [
  null,
  "Message d'erreur"
 ],
 "Error running semanage to discover system modifications": [
  null,
  "Erreur d’exécution de semanage pour découvrir les modifications du système"
 ],
 "Excellent password": [
  null,
  "Mot de passe excellent"
 ],
 "Existing disk image on host's file system": [
  null,
  "Image disque existante sur le système de fichiers de l’hôte"
 ],
 "Expand": [
  null,
  "Développer"
 ],
 "Expansion chassis": [
  null,
  "Châssis d’extension"
 ],
 "Failed": [
  null,
  "Échoué"
 ],
 "Failed to change firmware": [
  null,
  "Échec de la modification du micrologiciel"
 ],
 "Failed to change password": [
  null,
  "Échec de la modification du mot de passe"
 ],
 "Failed to clone VM $0": [
  null,
  "Echec du clonage de la VM $0"
 ],
 "Failed to fetch the IP addresses of the interfaces present in $0": [
  null,
  "Impossible de récupérer les adresses IP des interfaces présentes dans $0"
 ],
 "Failed to send key Ctrl+Alt+$0 to VM $1": [
  null,
  "Échec de l’envoi de la touche Ctrl+Alt+$0 à la VM $1"
 ],
 "Fewer than the maximum number of virtual CPUs should be enabled.": [
  null,
  "Un nombre inférieur au nombre maximal de processeurs virtuels doit être activé."
 ],
 "File": [
  null,
  "Fichier"
 ],
 "Filesystem directory": [
  null,
  "Répertoire des fichiers système"
 ],
 "Filter by name": [
  null,
  "Filtrer par nom"
 ],
 "Firmware": [
  null,
  "Micrologiciel"
 ],
 "Force reboot": [
  null,
  "Redémarrage forcé"
 ],
 "Force shut down": [
  null,
  "Arrêt forcé"
 ],
 "Format": [
  null,
  "Formater"
 ],
 "Forward mode": [
  null,
  "Mode de redirection"
 ],
 "Forwarding mode": [
  null,
  "Mode de redirection"
 ],
 "General": [
  null,
  "Général"
 ],
 "Generate automatically": [
  null,
  "Générer automatiquement"
 ],
 "GiB": [
  null,
  "Go"
 ],
 "Go to VMs list": [
  null,
  "Aller à la liste des VM"
 ],
 "Go to now": [
  null,
  "Aller à maintenant"
 ],
 "Handheld": [
  null,
  "Portable"
 ],
 "Hide additional options": [
  null,
  "Cacher les options supplémentaires"
 ],
 "Host": [
  null,
  "Hôte"
 ],
 "Host device": [
  null,
  "Périphérique hôte"
 ],
 "Host name": [
  null,
  "Nom de l'hôte"
 ],
 "Host should not be empty": [
  null,
  "Le nom d’hôte n’est peut-être pas vide"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "Les heures doivent être un nombre compris entre 0 et 23"
 ],
 "Hypervisor details": [
  null,
  "Détails sur l’hyperviseur"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP address": [
  null,
  "Adresse IP"
 ],
 "IP configuration": [
  null,
  "Configuration IP"
 ],
 "IPv4 address": [
  null,
  "Adresse IPv4"
 ],
 "IPv4 and IPv6": [
  null,
  "IPv4 et IPv6"
 ],
 "IPv4 network": [
  null,
  "Réseau IPv4"
 ],
 "IPv4 network should not be empty": [
  null,
  "Le réseau IPv4 ne doit pas être vide"
 ],
 "IPv4 only": [
  null,
  "IPv4 seulement"
 ],
 "IPv6 address": [
  null,
  "Adresse IPv6"
 ],
 "IPv6 network": [
  null,
  "Réseau IPv6"
 ],
 "IPv6 network should not be empty": [
  null,
  "Le réseau IPv6 ne doit pas être vide"
 ],
 "IPv6 only": [
  null,
  "IPv6 seulement"
 ],
 "Idle": [
  null,
  "inactif"
 ],
 "Immediately start VM": [
  null,
  "Démarrer immédiatement la VM"
 ],
 "Import": [
  null,
  "Importer"
 ],
 "Import VM": [
  null,
  "Importer une VM"
 ],
 "Import a virtual machine": [
  null,
  "Importer une machine virtuelle"
 ],
 "In most configurations, macvtap does not work for host to guest network communication.": [
  null,
  "Dans la plupart des configurations, « macvtap » ne fonctionne pas pour les communications en réseau entre hôte et invité."
 ],
 "Initiator": [
  null,
  "Initiateur"
 ],
 "Initiator IQN should not be empty": [
  null,
  "L’initiateur IQN ne doit pas rester vide"
 ],
 "Install": [
  null,
  "Installer"
 ],
 "Install software": [
  null,
  "Installer le logiciel"
 ],
 "Installation source": [
  null,
  "Source d’installation"
 ],
 "Installation source must not be empty": [
  null,
  "La source de l’installation ne doit pas être vide"
 ],
 "Installation type": [
  null,
  "Type d’installation"
 ],
 "Installing $0": [
  null,
  "Installation de $0"
 ],
 "Interface type": [
  null,
  "Type d’interface"
 ],
 "Invalid IPv4 address": [
  null,
  "Adresse IPv4 non valide"
 ],
 "Invalid IPv4 mask or prefix length": [
  null,
  "Longueur de masque ou de préfixe IPv4 non valide"
 ],
 "Invalid IPv6 address": [
  null,
  "Adresse IPv6 non valide"
 ],
 "Invalid IPv6 prefix": [
  null,
  "Adresse IPv6 non valide"
 ],
 "Invalid date format": [
  null,
  "Format de date non valide"
 ],
 "Invalid date format and invalid time format": [
  null,
  "Format de date non valide et format d’heure non valide"
 ],
 "Invalid file permissions": [
  null,
  "Les autorisations de fichier ne sont pas valides"
 ],
 "Invalid filename": [
  null,
  "Nom de fichier non valide"
 ],
 "Invalid time format": [
  null,
  "Format d’heure non valide"
 ],
 "Invalid timezone": [
  null,
  "Fuseau horaire incorrect"
 ],
 "IoT gateway": [
  null,
  "Passerelle IoT"
 ],
 "Isolated network": [
  null,
  "Réseau isolé"
 ],
 "LVM volume group": [
  null,
  "Groupe de volumes LVM"
 ],
 "Laptop": [
  null,
  "Portable"
 ],
 "Launch remote viewer": [
  null,
  "Lancer l’afficheur à distance"
 ],
 "Learn more": [
  null,
  "En savoir plus"
 ],
 "Leave the password blank if you do not wish to have a root account created": [
  null,
  "Laissez le mot de passe vide si vous ne souhaitez pas qu’un compte root soit créé"
 ],
 "Leave the password blank if you do not wish to have a user account created": [
  null,
  "Laissez le mot de passe vide si vous ne souhaitez pas qu’un compte d’utilisateur soit créé"
 ],
 "Libvirt did not detect any UEFI/OVMF firmware image installed on the host": [
  null,
  "Libvirt n’a détecté aucune image de micrologiciel UEFI/OVMF installée sur l’hôte"
 ],
 "Libvirt or hypervisor does not support UEFI": [
  null,
  "Libvirt ou l’hyperviseur ne prend pas en charge UEFI"
 ],
 "Loading resources": [
  null,
  "Chargement des ressources"
 ],
 "Loading system modifications...": [
  null,
  "Chargement des modifications système…"
 ],
 "Loading...": [
  null,
  "Chargement…"
 ],
 "Local install media (ISO image or distro install tree)": [
  null,
  ""
 ],
 "Log messages": [
  null,
  "Enregistrer les messages"
 ],
 "Low profile desktop": [
  null,
  "Bureau de profil bas"
 ],
 "Lunch box": [
  null,
  "Lunch Box"
 ],
 "MAC": [
  null,
  "MAC"
 ],
 "MAC address": [
  null,
  "Adresse MAC"
 ],
 "Machine must be shut off before changing bus type": [
  null,
  "La machine doit être arrêtée avant de changer de type de bus"
 ],
 "Main server chassis": [
  null,
  "Châssis principal du serveur"
 ],
 "Managing virtual machines": [
  null,
  "Gestion des machines virtuelles"
 ],
 "Manual connection": [
  null,
  "Connexion manuelle"
 ],
 "Manually": [
  null,
  "Manuellement"
 ],
 "Mask or prefix length": [
  null,
  "Masque ou Longueur du préfixe"
 ],
 "Mask or prefix length should not be empty": [
  null,
  "Le masque ou la longueur du préfixe ne doit pas être vide"
 ],
 "Maximum allocation": [
  null,
  "Allocation maximale"
 ],
 "Maximum memory could not be saved": [
  null,
  "La mémoire maximale n’a pas pu être sauvegardée"
 ],
 "Maximum number of virtual CPUs allocated for the guest OS": [
  null,
  "Nombre maximum de CPU virtuels alloués pour le système d'exploitation invité"
 ],
 "Maximum number of virtual CPUs allocated for the guest OS, which must be between 1 and $0": [
  null,
  "Nombre maximum de CPU virtuels alloués pour l’OS invité, doit être compris entre 1 et $0"
 ],
 "Maximum transmission unit": [
  null,
  "Unité maximale de transmission (MTU)"
 ],
 "Memory": [
  null,
  "Mémoire"
 ],
 "Memory could not be saved": [
  null,
  "La mémoire n’a pas pu être sauvegardée"
 ],
 "Memory must not be 0": [
  null,
  "La mémoire ne doit pas être 0"
 ],
 "Message to logged in users": [
  null,
  "Message aux utilisateurs connectés"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Mini PC": [
  null,
  "Mini PC"
 ],
 "Mini tower": [
  null,
  "Mini Tour"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "Les minutes doivent correspondre à un nombre compris entre 0 et 59"
 ],
 "Mode": [
  null,
  "Mode"
 ],
 "Model": [
  null,
  "Modèle"
 ],
 "Model type": [
  null,
  "Type de modèle"
 ],
 "Multi-system chassis": [
  null,
  "Châssis multi-système"
 ],
 "NAT to $0": [
  null,
  "NAT vers $0"
 ],
 "NIC $0 of VM $1 failed to change state": [
  null,
  "Échec du changement d’état du NIC $0 de la VM $1"
 ],
 "NTP server": [
  null,
  "Serveur NTP"
 ],
 "Name": [
  null,
  "Nom"
 ],
 "Name contains invalid characters": [
  null,
  "Le nom contient des caractères invalides"
 ],
 "Name must not be empty": [
  null,
  "Le nom ne doit pas être vide"
 ],
 "Name should not be empty": [
  null,
  "Le nom ne doit pas être vide"
 ],
 "Name: ": [
  null,
  "Nom : "
 ],
 "Need at least one NTP server": [
  null,
  "Besoin d’au moins un serveur NTP"
 ],
 "Netmask": [
  null,
  "Masque réseau"
 ],
 "Network $0 failed to get activated": [
  null,
  "Échec de l’activation du réseau $0"
 ],
 "Network $0 failed to get deactivated": [
  null,
  "Échec de la désactivation du réseau $0"
 ],
 "Network boot (PXE)": [
  null,
  "Démarrage réseau (PXE)"
 ],
 "Network file system": [
  null,
  "Système de fichiers par réseau (NFS)"
 ],
 "Network interface settings could not be saved": [
  null,
  "Les paramètres de l’interface réseau n’ont pas pu être enregistrés"
 ],
 "Network selection does not support PXE.": [
  null,
  "Le réseau sélectionné ne prend pas en charge PXE."
 ],
 "Networks": [
  null,
  "Réseaux"
 ],
 "New password was not accepted": [
  null,
  "Le nouveau mot de passe n’a pas été accepté"
 ],
 "New volume name": [
  null,
  "Nouveau nom de volume"
 ],
 "No VM is running or defined on this host": [
  null,
  "Aucune machine virtuelle n’est en cours d’exécution ou définie sur cet hôte"
 ],
 "No boot device found": [
  null,
  "Aucun périphérique de démarrage trouvé"
 ],
 "No connection available": [
  null,
  "Aucune connexion disponible"
 ],
 "No delay": [
  null,
  "Aucun délai"
 ],
 "No description": [
  null,
  "Aucune description"
 ],
 "No disks defined for this VM": [
  null,
  "Aucun disque défini pour cette machine virtuelle"
 ],
 "No network devices": [
  null,
  "Aucun périphérique réseau disponible"
 ],
 "No network interfaces defined for this VM": [
  null,
  "Aucune interface réseau définie pour cette machine virtuelle"
 ],
 "No network is defined on this host": [
  null,
  "Aucun réseau n’est défini sur cet hôte"
 ],
 "No networks available": [
  null,
  "Aucun réseau disponible"
 ],
 "No parent": [
  null,
  "Pas de parent"
 ],
 "No snapshots defined for this VM": [
  null,
  "Aucun instantané défini pour cette VM"
 ],
 "No state": [
  null,
  "Pas d'État"
 ],
 "No storage": [
  null,
  "Aucun stockage"
 ],
 "No storage pool is defined on this host": [
  null,
  "Aucun pool de stockage n’a été défini sur cet hôte"
 ],
 "No storage pools available": [
  null,
  "Aucun pool de stockage disponible"
 ],
 "No storage volumes defined for this storage pool": [
  null,
  "Aucun volume de stockage n’a été défini pour ce pool de stockage"
 ],
 "No such file or directory": [
  null,
  "Aucun fichier ou répertoire de ce nom"
 ],
 "No system modifications": [
  null,
  "Aucune modification système"
 ],
 "No virtual networks": [
  null,
  "Aucun réseau virtuel"
 ],
 "Non-persistent network cannot be deleted. It ceases to exists when it's deactivated.": [
  null,
  "Un réseau non persistant ne peut pas être supprimé. Il cesse d’exister quand il est désactivé."
 ],
 "Non-persistent storage pool cannot be deleted. It ceases to exists when it's deactivated.": [
  null,
  "Un réseau non persistant ne peut pas être supprimé. Il cesse d’exister quand il est désactivé."
 ],
 "None": [
  null,
  "Aucun"
 ],
 "None (isolated network)": [
  null,
  "Aucune (réseau isolé)"
 ],
 "Not a valid private key": [
  null,
  "Clé privée non valide"
 ],
 "Not synchronized": [
  null,
  "Non synchronisé"
 ],
 "Notebook": [
  null,
  "Ordinateur portable"
 ],
 "Ok": [
  null,
  "Ok"
 ],
 "Old password not accepted": [
  null,
  "Ancien mot de passe non accepté"
 ],
 "One or more selected volumes are used by domains. Detach the disks first to allow volume deletion.": [
  null,
  "Un ou plusieurs modules sélectionnés sont utiliés par les domaines. Détachez d’abords les disques pour permettre la suppression du volume."
 ],
 "Only editable when the guest is shut off": [
  null,
  "Modifiable uniquement quand l’invité est fermé"
 ],
 "Open": [
  null,
  "Ouvrir"
 ],
 "Operating system": [
  null,
  "Système d’exploitation"
 ],
 "Operation is in progress": [
  null,
  "Opération en cours"
 ],
 "Other": [
  null,
  "Autre"
 ],
 "Overview": [
  null,
  "Aperçu"
 ],
 "PackageKit crashed": [
  null,
  "Plantage de « PackageKit »"
 ],
 "Parent snapshot": [
  null,
  "Aperçu des parents"
 ],
 "Password is not acceptable": [
  null,
  "Le mot de passe n’est pas acceptable"
 ],
 "Password is too weak": [
  null,
  "Le mot de passe est trop faible"
 ],
 "Password not accepted": [
  null,
  "Mot de passe non accepté"
 ],
 "Paste": [
  null,
  "Coller"
 ],
 "Path": [
  null,
  "Chemin"
 ],
 "Path on host's filesystem": [
  null,
  "Chemin d’accès sur le système de fichiers de l’hôte"
 ],
 "Path to ISO file on host's file system": [
  null,
  "Chemin d’accès au fichier ISO sur le système de fichiers de l’hôte"
 ],
 "Path to file": [
  null,
  "Chemin d’accès au fichier"
 ],
 "Path to file on host's file system": [
  null,
  "Chemin d’accès au fichier ISO sur le système de fichiers de l’hôte"
 ],
 "Pause": [
  null,
  "Suspendre"
 ],
 "Paused": [
  null,
  "Mis en pause"
 ],
 "Peripheral chassis": [
  null,
  "Châssis périphérique"
 ],
 "Persistence": [
  null,
  "Persistance"
 ],
 "Persistent": [
  null,
  "Persistant"
 ],
 "Physical disk device": [
  null,
  "Périphérique de disque physique"
 ],
 "Physical disk device on host": [
  null,
  "Périphérique de disque physique sur l’hôte"
 ],
 "Pick date": [
  null,
  "Choisissez une date"
 ],
 "Pizza box": [
  null,
  "Pizza Box"
 ],
 "Please choose a storage pool": [
  null,
  "Veuillez choisir un pool de stockage"
 ],
 "Please choose a volume": [
  null,
  "Veuillez choisir un volume"
 ],
 "Please enter new volume name": [
  null,
  "Veuillez saisir un nouveau nom de volume"
 ],
 "Please start the virtual machine to access its console.": [
  null,
  "Veuillez démarrer la machine virtuelle pour accéder à sa console."
 ],
 "Plug": [
  null,
  "Connecteur"
 ],
 "Pool": [
  null,
  "Pool"
 ],
 "Pool needs to be active to create volume": [
  null,
  "Le pool doit être actif pour créer du volume"
 ],
 "Pool type doesn't support volume creation": [
  null,
  "Le type de pool ne supporte pas la création de volume"
 ],
 "Pool's volumes are used by VMs ": [
  null,
  "Les volumes de pool sont utilisés par les VM "
 ],
 "Port": [
  null,
  "Port"
 ],
 "Portable": [
  null,
  "Portable"
 ],
 "Preferred number of sockets to expose to the guest.": [
  null,
  "Nombre choisi de sockets à exposer à l’invité."
 ],
 "Prefix": [
  null,
  "Préfixe"
 ],
 "Prefix length": [
  null,
  "Longueur du préfixe"
 ],
 "Prefix length should not be empty": [
  null,
  "La longueur du préfixe ne doit pas être vide"
 ],
 "Present": [
  null,
  "Présent"
 ],
 "Previously taken snapshots allow you to revert to an earlier state if something goes wrong": [
  null,
  "Les clichés pris précédemment vous permettent de revenir à un état antérieur si quelque chose ne va pas"
 ],
 "Private": [
  null,
  "Privé"
 ],
 "Product": [
  null,
  "Produit"
 ],
 "Profile": [
  null,
  "Profil"
 ],
 "Prompting via ssh-add timed out": [
  null,
  "L’invite via ssh-add a expiré"
 ],
 "Prompting via ssh-keygen timed out": [
  null,
  "L’invite via ssh-keygen a expiré"
 ],
 "Protocol": [
  null,
  "Protocole"
 ],
 "RAID chassis": [
  null,
  "Châssis RAID"
 ],
 "Rack mount chassis": [
  null,
  "Châssis de montage en rack"
 ],
 "Read-only": [
  null,
  "Lecture seule"
 ],
 "Reboot": [
  null,
  "Redémarrer"
 ],
 "Remote URL": [
  null,
  "URL distante"
 ],
 "Remote viewer details": [
  null,
  "Détails de la visionneuse à distance"
 ],
 "Removals:": [
  null,
  "Suppressions :"
 ],
 "Remove": [
  null,
  "Retirer"
 ],
 "Removing $0": [
  null,
  "Suppression de $0"
 ],
 "Resume": [
  null,
  "Reprendre"
 ],
 "Revert": [
  null,
  "Rétablir"
 ],
 "Revert to snapshot $0": [
  null,
  "Revenir à l'instantané $0"
 ],
 "Reverting to this snapshot will take the VM back to the time of the snapshot and the current state will be lost, along with any data not captured in a snapshot": [
  null,
  "Le retour à cet instantané ramènera la VM au moment de l'instantané et l'état actuel sera perdu, ainsi que toutes les données non saisies dans un instantané"
 ],
 "Root password": [
  null,
  "Mot de passe administrateur"
 ],
 "Route to $0": [
  null,
  "Routage vers $0"
 ],
 "Routed network": [
  null,
  "Réseau routé"
 ],
 "Run": [
  null,
  "Exécuter"
 ],
 "Run unattended installation": [
  null,
  "Exécuter une installation sans surveillance"
 ],
 "Run when host boots": [
  null,
  "Démarrer quand l’hôte est amorcé"
 ],
 "Running": [
  null,
  "En cours"
 ],
 "SPICE TLS port": [
  null,
  "Port SPICE TLS"
 ],
 "SPICE address": [
  null,
  "Adresse SPICE"
 ],
 "SPICE port": [
  null,
  "Port SPICE"
 ],
 "Save": [
  null,
  "sauvegarder"
 ],
 "Sealed-case PC": [
  null,
  "PC scellé"
 ],
 "Select console type": [
  null,
  "Sélectionnez le type de console"
 ],
 "Send key": [
  null,
  "Envoi de la clé"
 ],
 "Send non-maskable interrupt": [
  null,
  "Envoyer une interruption non masquable"
 ],
 "Serial console": [
  null,
  "Console série"
 ],
 "Session": [
  null,
  "Session"
 ],
 "Set DHCP range": [
  null,
  "Définir plage DHCP"
 ],
 "Set manually": [
  null,
  "Définir manuellement"
 ],
 "Set time": [
  null,
  "Régler l’heure"
 ],
 "Setting the user passwords for unattended installation requires starting the VM when creating it": [
  null,
  "La définition des mots de passe utilisateur pour les installations sans surveillance nécessite le démarrage de la VM lors de sa création"
 ],
 "Shell script": [
  null,
  "Script d’interpréteur de commande"
 ],
 "Shift+Insert": [
  null,
  "Maj+Inser"
 ],
 "Show additional options": [
  null,
  "Actions supplémentaires"
 ],
 "Shut down": [
  null,
  "Fermeture"
 ],
 "Shut off": [
  null,
  "Éteindre"
 ],
 "Shut off the VM in order to edit firmware configuration": [
  null,
  "Éteindre la VM afin de modifier la configuration du micrologiciel"
 ],
 "Shutting down": [
  null,
  "Fermeture"
 ],
 "Single rank": [
  null,
  "Rang unique"
 ],
 "Size": [
  null,
  "Taille"
 ],
 "Snapshot failed to be created": [
  null,
  "L'instantané n'a pas été créé"
 ],
 "Snapshots": [
  null,
  "Instantanés"
 ],
 "Sockets": [
  null,
  "Prises"
 ],
 "Source": [
  null,
  "La source"
 ],
 "Source format": [
  null,
  "Format de la source"
 ],
 "Source path": [
  null,
  "Chemin d’accès à la source"
 ],
 "Source path should not be empty": [
  null,
  "Le chemin de la source ne doit pas être vide"
 ],
 "Source should start with http, ftp or nfs protocol": [
  null,
  "La source devrait commencer par le protocole http, ftp ou nfs"
 ],
 "Source volume group": [
  null,
  "Renommer le groupe de volumes"
 ],
 "Space-saving computer": [
  null,
  "Ordinateur gain de place"
 ],
 "Specific time": [
  null,
  "Temps spécifique"
 ],
 "Start": [
  null,
  "Démarrer"
 ],
 "Start libvirt": [
  null,
  "Lancer libvirt"
 ],
 "Start pool when host boots": [
  null,
  "Démarrer le pool quand l’hôte est amorcé"
 ],
 "Start should not be empty": [
  null,
  "Le démarrage ne doit pas être vide"
 ],
 "Startup": [
  null,
  "Démarrage"
 ],
 "State": [
  null,
  "État"
 ],
 "Stick PC": [
  null,
  "Stick PC"
 ],
 "Storage": [
  null,
  "Stockage"
 ],
 "Storage pool $0 failed to get activated": [
  null,
  "Échec de l’activation du pool de stockage $0"
 ],
 "Storage pool $0 failed to get deactivated": [
  null,
  "Échec de la désactivation du pool de stockage $0"
 ],
 "Storage pool failed to be created": [
  null,
  "Le pool de stockage n’a pas pu être créé"
 ],
 "Storage pool name": [
  null,
  "Nom du pool de stockage"
 ],
 "Storage pools": [
  null,
  "Pools de stockage"
 ],
 "Storage size must not be 0": [
  null,
  "La taille de stockage ne doit pas être de 0"
 ],
 "Storage volume": [
  null,
  "Volume de stockage"
 ],
 "Storage volume size must not exceed the storage pool's capacity ($0 $1)": [
  null,
  "La taille du volume de stockage ne doit pas dépasser la capacité du pool de stockage ($0 $1)"
 ],
 "Storage volumes": [
  null,
  "Volumes de stockage"
 ],
 "Storage volumes could not be deleted": [
  null,
  "Les volumes de stockage n’ont pas pu être supprimés"
 ],
 "Sub-Chassis": [
  null,
  "Sous-châssis"
 ],
 "Sub-Notebook": [
  null,
  "Sub-Notebook"
 ],
 "Suspended (PM)": [
  null,
  "Mode Attente (PM)"
 ],
 "Synchronized": [
  null,
  "Synchronisé"
 ],
 "Synchronized with $0": [
  null,
  "Synchronisé avec $0"
 ],
 "Synchronizing": [
  null,
  "Synchronisation"
 ],
 "System": [
  null,
  "Système"
 ],
 "Tablet": [
  null,
  "Tablette"
 ],
 "Target": [
  null,
  "Cible"
 ],
 "Target path": [
  null,
  "Chemin cible"
 ],
 "Target path should not be empty": [
  null,
  "Le chemin cible ne doit pas rester vide"
 ],
 "The $0 could not be deleted": [
  null,
  "$0 n’a pas pu être supprimé"
 ],
 "The VM is running and will be forced off before deletion.": [
  null,
  "La VM est en cours d’exécution, son arrêt sera forcé avant la suppression."
 ],
 "The VM needs to be running or shut off to detach this device": [
  null,
  "La VM doit être en marche ou arrêtée pour détacher ce périphérique"
 ],
 "The directory on the server being exported": [
  null,
  "Le répertoire du serveur à exporter"
 ],
 "The logged in user is not permitted to view system modifications": [
  null,
  "L’utilisateur actuellement connecté n’est pas autorisé à voir les modifications système"
 ],
 "The passwords do not match.": [
  null,
  "Le mot de passe ne correspond pas."
 ],
 "The pool is empty": [
  null,
  "La pool est vide"
 ],
 "The selected operating system does not support unattended installation": [
  null,
  "Le système d’exécution sélectionné ne prend pas en charge les installations sans surveillance"
 ],
 "The selected operating system has minimum memory requirement of $0 $1": [
  null,
  "Le système d’exploitation sélectionné a un besoin en mémoire minimum de $0 $1"
 ],
 "The selected operating system has minimum storage size requirement of $0 $1": [
  null,
  "Le système d’exécution sélectionné a un besoin en mémoire minimum de $0 $1"
 ],
 "The storage pool could not be deleted": [
  null,
  "Le pool de stockage n’a pas pu être supprimé"
 ],
 "This VM is transient. Shut it down if you wish to delete it.": [
  null,
  "Cette VM est temporaire. Éteignez-la si vous souhaitez la supprimer."
 ],
 "This volume is already used by another VM.": [
  null,
  "Ce volume est déjà utilisé par une autre VM."
 ],
 "This volume is already used by: ": [
  null,
  "Ce volume est déjà utilisé par : "
 ],
 "Threads per core": [
  null,
  "Threads par noyaux"
 ],
 "Time zone": [
  null,
  "Fuseau horaire"
 ],
 "Today": [
  null,
  "Aujourd'hui"
 ],
 "Total size: $0": [
  null,
  "Taille totale : $0"
 ],
 "Tower": [
  null,
  "Tower"
 ],
 "Transient VMs don't support editing firmware configuration": [
  null,
  "Les machines virtuelles temporaires ne permettent pas de modifier la configuration du micrologiciel"
 ],
 "Troubleshoot": [
  null,
  "Dépannage"
 ],
 "Trying to synchronize with $0": [
  null,
  "Essaye de synchroniser avec $0"
 ],
 "Type": [
  null,
  "Type"
 ],
 "Type ID": [
  null,
  "ID type"
 ],
 "URL (ISO image or distro install tree)": [
  null,
  ""
 ],
 "Unique name": [
  null,
  "Nom unique"
 ],
 "Unique network name": [
  null,
  "Nom du réseau unique"
 ],
 "Unit": [
  null,
  "Unité"
 ],
 "Unknown": [
  null,
  "Inconnu"
 ],
 "Unknown firmware": [
  null,
  "Micrologiciel inconnu"
 ],
 "Unplug": [
  null,
  "Débrancher"
 ],
 "Up to $0 $1 available on the default location": [
  null,
  ""
 ],
 "Up to $0 $1 available on the host": [
  null,
  ""
 ],
 "Url": [
  null,
  "Url"
 ],
 "Usage": [
  null,
  "Utilisation"
 ],
 "Use existing": [
  null,
  "Utiliser l’existant"
 ],
 "Used": [
  null,
  "Utilisé"
 ],
 "Used by": [
  null,
  "Utilisé par"
 ],
 "User login must not be empty when user password is set": [
  null,
  ""
 ],
 "User password": [
  null,
  "Mot de passe utilisateur"
 ],
 "User password must not be empty when user login is set": [
  null,
  ""
 ],
 "VCPU settings could not be saved": [
  null,
  "Les paramètres de configuration de VCPU n’ont pas pu être sauvegardés"
 ],
 "VM $0 already exists": [
  null,
  "VM $0 existe déjà"
 ],
 "VM $0 does not exist on $1 connection": [
  null,
  "VM $0 n'existe pas sur la connexion $1"
 ],
 "VM $0 failed to force reboot": [
  null,
  "Échec du redémarrage forcé de la VM $0"
 ],
 "VM $0 failed to force shutdown": [
  null,
  "Échec de l’arrêt forcé de la VM $0"
 ],
 "VM $0 failed to get deleted": [
  null,
  "Échec de la suppression de la VM $0"
 ],
 "VM $0 failed to get installed": [
  null,
  "Échec de l’installation de la VM $0"
 ],
 "VM $0 failed to pause": [
  null,
  "Échec de la mise en pause de la VM $0"
 ],
 "VM $0 failed to reboot": [
  null,
  "Échec du redémarrage de la VM $0"
 ],
 "VM $0 failed to resume": [
  null,
  "Échec de la reprise de la VM $0"
 ],
 "VM $0 failed to send NMI": [
  null,
  "Échec de l’envoi NMI de la VM $0"
 ],
 "VM $0 failed to shutdown": [
  null,
  "Échec de l’arrêt de la VM $0"
 ],
 "VM $0 failed to start": [
  null,
  "Échec du démarrage de la VM $0"
 ],
 "VM state": [
  null,
  "État VM"
 ],
 "VNC TLS port": [
  null,
  "Port VNC TLS"
 ],
 "VNC address": [
  null,
  "Adresse VNC"
 ],
 "VNC console": [
  null,
  "Console VNC"
 ],
 "VNC port": [
  null,
  "Port VNC"
 ],
 "Vendor": [
  null,
  "Fournisseur"
 ],
 "View automation script": [
  null,
  "Afficher le script d’automation"
 ],
 "Virtual Machines": [
  null,
  "Machines virtuelles"
 ],
 "Virtual machines": [
  null,
  "Machines virtuelles"
 ],
 "Virtual machines management": [
  null,
  "Gestion des machines virtuelles"
 ],
 "Virtual network": [
  null,
  "Réseau virtuel"
 ],
 "Virtual network failed to be created": [
  null,
  "Le réseau virtuel n’a pas pu être créé"
 ],
 "Virtualization service (libvirt) is not active": [
  null,
  "Le service de virtualisation (libvirt) n’est pas actif"
 ],
 "Volume": [
  null,
  "Volume"
 ],
 "Volume failed to be created": [
  null,
  "Le volume n’a pas pu être créé"
 ],
 "Volume group name": [
  null,
  "Nom du groupe de volumes"
 ],
 "Volume group name should not be empty": [
  null,
  "Le nom du groupe de volumes ne doit pas être vide"
 ],
 "WWPN": [
  null,
  "WWPN"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "Attente de la fin des autres opérations de gestion du logiciel"
 ],
 "Writeable": [
  null,
  "Ecrivable"
 ],
 "Writeable and shared": [
  null,
  "Ecrivable et partagé"
 ],
 "Yesterday": [
  null,
  "Hier"
 ],
 "You need to select the most closely matching operating system": [
  null,
  "Vous devez sélectionner le système d’exploitation le plus proche"
 ],
 "[$0 bytes of binary data]": [
  null,
  "[ $0 octets de données binaires]"
 ],
 "[binary data]": [
  null,
  "[données binaires]"
 ],
 "[no data]": [
  null,
  "[pas de données]"
 ],
 "active": [
  null,
  "actif"
 ],
 "bridge": [
  null,
  "pont"
 ],
 "cdrom": [
  null,
  "CD ROM"
 ],
 "custom": [
  null,
  "personnalisé"
 ],
 "direct": [
  null,
  "direct"
 ],
 "disabled": [
  null,
  "désactivé"
 ],
 "disk": [
  null,
  "disque"
 ],
 "down": [
  null,
  "arrêté"
 ],
 "edit": [
  null,
  "modifier"
 ],
 "enabled": [
  null,
  "activée"
 ],
 "ethernet": [
  null,
  "ethernet"
 ],
 "host": [
  null,
  "hôte"
 ],
 "host device": [
  null,
  "périphérique hôte"
 ],
 "host passthrough": [
  null,
  "host passthrough"
 ],
 "hostdev": [
  null,
  "hostdev"
 ],
 "iSCSI direct target": [
  null,
  "Cible directe iSCSI"
 ],
 "iSCSI initiator IQN": [
  null,
  "iSCSI Initiator IQN"
 ],
 "iSCSI target": [
  null,
  "Cible iSCSI"
 ],
 "iSCSI target IQN": [
  null,
  "Cible iSCSI IQN"
 ],
 "iso": [
  null,
  "iso"
 ],
 "libvirt": [
  null,
  "libvirt"
 ],
 "mcast": [
  null,
  "mcast"
 ],
 "network": [
  null,
  "réseau"
 ],
 "no": [
  null,
  "non"
 ],
 "no state saved": [
  null,
  "aucun état n'est sauvé"
 ],
 "pxe": [
  null,
  "pxe"
 ],
 "qcow2": [
  null,
  "qcow2"
 ],
 "qemu": [
  null,
  "qemu"
 ],
 "redirected device": [
  null,
  "périphérique redirigé"
 ],
 "server": [
  null,
  "serveur"
 ],
 "show less": [
  null,
  "montrer moins"
 ],
 "show more": [
  null,
  "montrer plus"
 ],
 "udp": [
  null,
  "UDP"
 ],
 "up": [
  null,
  "en cours"
 ],
 "user": [
  null,
  "utilisateur"
 ],
 "vCPU count": [
  null,
  "Nombre de vCPU"
 ],
 "vCPU maximum": [
  null,
  "vCPU Maximum"
 ],
 "vCPUs": [
  null,
  "vCPU"
 ],
 "vhostuser": [
  null,
  "vhostuser"
 ],
 "view more...": [
  null,
  "voir plus..."
 ],
 "virt-install package needs to be installed on the system in order to clone VMs": [
  null,
  "Le paquet virt-install doit être installé sur le système pour pouvoir créer les nouvelles VM"
 ],
 "virt-install package needs to be installed on the system in order to create new VMs": [
  null,
  "Le paquet virt-install doit être installé sur le système pour pouvoir créer les nouvelles VM"
 ],
 "virt-install package needs to be installed on the system in order to edit this attribute": [
  null,
  "Le paquet virt-install doit être installé sur le système pour pouvoir créer les nouvelles VM"
 ],
 "vm": [
  null,
  "vm"
 ],
 "yes": [
  null,
  "oui"
 ]
});
