cockpit.locale({
 "": {'plural-forms':function(n) {
var nplurals, plural;
nplurals=1; plural=0;
return plural;
},
  "language": "ko",
  "x-generator": "Weblate 4.6"
 },
 "$0 CPU configuration": [
  null,
  "$0 CPU 구성"
 ],
 "$0 Network": [
  "$0 Networks",
  "$0 네트워크"
 ],
 "$0 Storage pool": [
  "$0 Storage pools",
  "$0 저장소 풀"
 ],
 "$0 day": [
  "$0 days",
  "$0 일"
 ],
 "$0 hour": [
  "$0 hours",
  "$0 시"
 ],
 "$0 is available for most operating systems. To install it, search for it in GNOME Software or run the following:": [
  null,
  "$0 대부분의 운영 체제에서 사용 할 수 있습니다. 설치하려면 그놈 소프트웨어에서 검색하거나 다음을 실행하십시오:"
 ],
 "$0 is not available from any repository.": [
  null,
  "$0는 저장소에서 사용 할 수 없습니다."
 ],
 "$0 memory adjustment": [
  null,
  "$0 메모리 조정"
 ],
 "$0 minute": [
  "$0 minutes",
  "$0 분"
 ],
 "$0 month": [
  "$0 months",
  "$0 달"
 ],
 "$0 network": [
  null,
  "$0 네트워크"
 ],
 "$0 vCPU": [
  "$0 vCPUs",
  "$0 vCPUs"
 ],
 "$0 vCPU details": [
  null,
  "$0 vCPU 세부 정보"
 ],
 "$0 virtual network interface settings": [
  null,
  "$0 가상 네트워크 연결장치 설정"
 ],
 "$0 week": [
  "$0 weeks",
  "$0 주"
 ],
 "$0 will be installed.": [
  null,
  "$0가 설치됩니다."
 ],
 "$0 year": [
  "$0 years",
  "$0 년"
 ],
 "1 day": [
  null,
  "1 일"
 ],
 "1 hour": [
  null,
  "1 시간"
 ],
 "1 minute": [
  null,
  "1분"
 ],
 "1 week": [
  null,
  "1주"
 ],
 "20 minutes": [
  null,
  "20분"
 ],
 "40 minutes": [
  null,
  "40 분"
 ],
 "5 minutes": [
  null,
  "5분"
 ],
 "6 hours": [
  null,
  "6 시간"
 ],
 "60 minutes": [
  null,
  "60 분"
 ],
 "Absent": [
  null,
  "부재"
 ],
 "Access": [
  null,
  "접근"
 ],
 "Activate": [
  null,
  "활성화"
 ],
 "Activate the storage pool to administer volumes": [
  null,
  "볼륨을 관리하려면 저장소 풀을 활성화하세요"
 ],
 "Add": [
  null,
  "추가"
 ],
 "Add disk": [
  null,
  "디스크 추가"
 ],
 "Add network interface": [
  null,
  "네트워크 연결장치 추가"
 ],
 "Add virtual network interface": [
  null,
  "가상 네트워크 연결장치 추가"
 ],
 "Additional": [
  null,
  "추가"
 ],
 "Additional packages:": [
  null,
  "추가 꾸러미 :"
 ],
 "Address": [
  null,
  "주소"
 ],
 "Address not within subnet": [
  null,
  "서브넷 내에 없는 주소"
 ],
 "Advanced TCA": [
  null,
  "고급 TCA"
 ],
 "After deleting the snapshot, all its captured content will be lost.": [
  null,
  "스냅샷을 삭제하면, 캡춰된 모든 내용이 손실됩니다."
 ],
 "All": [
  null,
  "모두"
 ],
 "All logs": [
  null,
  "모든 로그"
 ],
 "All-in-one": [
  null,
  "일체형"
 ],
 "Always attach": [
  null,
  "항상 연결"
 ],
 "Ansible": [
  null,
  "Ansible"
 ],
 "Ansible roles documentation": [
  null,
  "Ansible 역할 문서"
 ],
 "Apply": [
  null,
  "적용"
 ],
 "Attaching it will make this disk shareable for every VM using it.": [
  null,
  "연결하면 이를 사용하는 모든 VM에서 이 디스크를 공유 할 수 있습니다."
 ],
 "Automatic": [
  null,
  "자동"
 ],
 "Automatically start libvirt on boot": [
  null,
  "부트시 자동으로 libvirt 시작"
 ],
 "Automatically using NTP": [
  null,
  "자동으로 NTP 사용"
 ],
 "Automatically using specific NTP servers": [
  null,
  "특정 NTP 서버를 자동으로 사용"
 ],
 "Automation script": [
  null,
  "자동 스크립트"
 ],
 "Autostart": [
  null,
  "자동 시작"
 ],
 "Blade": [
  null,
  "블레이드"
 ],
 "Blade enclosure": [
  null,
  "블레이드 인클로저"
 ],
 "Blocked": [
  null,
  "차단됩니다"
 ],
 "Boot order": [
  null,
  "부팅 순서"
 ],
 "Boot order settings could not be saved": [
  null,
  "부팅 순서 설정을 저장 할 수 없습니다"
 ],
 "Bus": [
  null,
  "버스"
 ],
 "Bus expansion chassis": [
  null,
  "버스 확장 섀시"
 ],
 "CD/DVD disc": [
  null,
  "CD/DVD 디스크"
 ],
 "CPU": [
  null,
  "CPU"
 ],
 "CPU configuration could not be saved": [
  null,
  "CPU 구성을 저장 할 수 없습니다"
 ],
 "CPU type": [
  null,
  "CPU 유형"
 ],
 "Cache": [
  null,
  "캐쉬"
 ],
 "Cancel": [
  null,
  "취소"
 ],
 "Cannot schedule event in the past": [
  null,
  "이전 이벤트를 예약할 수 없습니다"
 ],
 "Capacity": [
  null,
  "용량"
 ],
 "Change": [
  null,
  "변경"
 ],
 "Change firmware": [
  null,
  "펌웨어 변경"
 ],
 "Change system time": [
  null,
  "시스템 시간 변경"
 ],
 "Changes will take effect after shutting down the VM": [
  null,
  "변경은 VM 종료 후에 적용됩니다"
 ],
 "Checking installed software": [
  null,
  "설치된 소프트웨어 확인 중"
 ],
 "Choose an operating system": [
  null,
  "운영 체제를 선택하십시오"
 ],
 "Clicking \"Launch remote viewer\" will download a .vv file and launch $0.": [
  null,
  "\"원격 뷰어 시작\"을 누르면 .vv 파일을 내려받기 하고 $0를 시작합니다."
 ],
 "Clone": [
  null,
  "복제"
 ],
 "Close": [
  null,
  "닫기"
 ],
 "Cloud base image": [
  null,
  "클라우드 기반 이미지"
 ],
 "Cloud init parameters": [
  null,
  "클라우드 init 매개변수"
 ],
 "Compact PCI": [
  null,
  "PCI 압축"
 ],
 "Confirm this action": [
  null,
  "작업 확인"
 ],
 "Connect": [
  null,
  "연결"
 ],
 "Connect with any viewer application for following protocols": [
  null,
  "다음 통신규약에 뷰어 응용프로그램에 연결합니다"
 ],
 "Connecting to virtualization service": [
  null,
  "가상화 서비스에 연결 중입니다"
 ],
 "Connection": [
  null,
  "연결"
 ],
 "Console": [
  null,
  "콘솔"
 ],
 "Convertible": [
  null,
  "변환 가능"
 ],
 "Copy": [
  null,
  "복사"
 ],
 "Copy to clipboard": [
  null,
  "클립보드로 복사"
 ],
 "Cores per socket": [
  null,
  "소켓당 코어 수"
 ],
 "Could not revert to snapshot": [
  null,
  "스냅샷으로 전환 할 수 없습니다"
 ],
 "Crashed": [
  null,
  "충돌"
 ],
 "Create": [
  null,
  "생성"
 ],
 "Create VM": [
  null,
  "가상 머신 만들기"
 ],
 "Create a clone VM based on $0": [
  null,
  "$0을 기반으로 복제 VM 만들기"
 ],
 "Create new": [
  null,
  "새로 만들기"
 ],
 "Create new task file with this content.": [
  null,
  "이 컨텐츠로 새 작업 파일을 만듭니다."
 ],
 "Create new virtual machine": [
  null,
  "새로운 가상 머신 만들기"
 ],
 "Create new volume": [
  null,
  "새로운 볼륨 만들기"
 ],
 "Create snapshot": [
  null,
  "스냅샷 만들기"
 ],
 "Create storage pool": [
  null,
  "저장소 풀 만들기"
 ],
 "Create storage volume": [
  null,
  "저장소 볼륨 만들기"
 ],
 "Create virtual network": [
  null,
  "가상 네트워크 만들기"
 ],
 "Create volume": [
  null,
  "볼륨 만들기"
 ],
 "Creating VM": [
  null,
  "VM 생성 중"
 ],
 "Creating VM installation": [
  null,
  "VM 설치 생성 중"
 ],
 "Creation of VM $0 failed": [
  null,
  "VM $0 생성이 실패했습니다"
 ],
 "Creation time": [
  null,
  "생성 시간"
 ],
 "Ctrl+Alt+$0": [
  null,
  "Ctrl+Alt+$0"
 ],
 "Ctrl+Insert": [
  null,
  "Ctrl+Insert"
 ],
 "Current": [
  null,
  "현재"
 ],
 "Current allocation": [
  null,
  "현재 할당"
 ],
 "Custom firmware: $0": [
  null,
  "사용자 지정 펌웨어: $0"
 ],
 "Custom path": [
  null,
  "사용자 지정 경로"
 ],
 "DHCP range": [
  null,
  "DHCP 범위"
 ],
 "Deactivate": [
  null,
  "비활성화"
 ],
 "Delay": [
  null,
  "지연"
 ],
 "Delete": [
  null,
  "삭제"
 ],
 "Delete $0 volume": [
  "Delete $0 volumes",
  "$0 볼륨 삭제"
 ],
 "Delete associated storage files:": [
  null,
  "관련된 저장소 파일 삭제:"
 ],
 "Delete content": [
  null,
  "내용 삭제"
 ],
 "Delete storage pool $0": [
  null,
  "저장소 풀 $0 삭제"
 ],
 "Delete the volumes inside this pool": [
  null,
  "이 풀 안에 있는 볼륨을 삭제합니다"
 ],
 "Deleting an inactive storage pool will only undefine the pool. Its content will not be deleted.": [
  null,
  "비활성화된 저장소 풀 삭제는 풀만 정의 해제하면 됩니다. 내용는 삭제되지 않습니다."
 ],
 "Description": [
  null,
  "설명"
 ],
 "Desktop": [
  null,
  "데스크탑"
 ],
 "Desktop viewer": [
  null,
  "데스크탑 뷰어"
 ],
 "Detach the disks using this pool from any VMs before attempting deletion.": [
  null,
  "삭제를 시도하기 전에 VM에서 이 풀을 사용하는 디스크를 분리하십시오."
 ],
 "Detachable": [
  null,
  "분리 가능"
 ],
 "Device": [
  null,
  "장치"
 ],
 "Devices": [
  null,
  "장치"
 ],
 "Disconnect": [
  null,
  "연결 끊김"
 ],
 "Disconnected from serial console. Click the connect button.": [
  null,
  "시리얼 콘솔에서 연결이 끊어졌습니다. 연결 버튼을 눌러주세요."
 ],
 "Disk $0 fail to get detached from VM $1": [
  null,
  "디스크 $0 가 VM $1에서 분리되지 않음"
 ],
 "Disk failed to be attached": [
  null,
  "디스크를 연결하지 못했습니다"
 ],
 "Disk failed to be created": [
  null,
  "디스크를 생성하지 못했습니다"
 ],
 "Disk image file": [
  null,
  "디스크 이미지 파일"
 ],
 "Disk settings could not be saved": [
  null,
  "디스크 설정을 저장 할 수 없습니다"
 ],
 "Disk-only snapshot": [
  null,
  "디스크-전용 스냅샷"
 ],
 "Disks": [
  null,
  "디스크"
 ],
 "Docking station": [
  null,
  "도킹 스테이션"
 ],
 "Domain has crashed": [
  null,
  "도메인이 충돌했습니다"
 ],
 "Domain is blocked on resource": [
  null,
  "도메인은 리소스에서 차단되었습니다"
 ],
 "Download an OS": [
  null,
  "OS 내려받기"
 ],
 "Downloading $0": [
  null,
  "$0 내려받기 중"
 ],
 "Dual rank": [
  null,
  "듀얼 랭크(Dual Rank)"
 ],
 "Dying": [
  null,
  "종료 중"
 ],
 "Edit": [
  null,
  "편집"
 ],
 "Edit $0 attributes": [
  null,
  "$0 속성 편집"
 ],
 "Embedded PC": [
  null,
  "임베디드 PC"
 ],
 "Emulated machine": [
  null,
  "에뮬레이트된 기기"
 ],
 "End": [
  null,
  "종료"
 ],
 "End should not be empty": [
  null,
  "끝은 비워둘 수 없습니다"
 ],
 "Error message": [
  null,
  "오류 메시지"
 ],
 "Error running semanage to discover system modifications": [
  null,
  "시스템 수정을 검색하기 위해 semanage 실행 중 오류 발생"
 ],
 "Excellent password": [
  null,
  "우수한 암호"
 ],
 "Existing disk image on host's file system": [
  null,
  "호스트의 파일 시스템에서 기존 디스크 이미지"
 ],
 "Expand": [
  null,
  "확장"
 ],
 "Expansion chassis": [
  null,
  "확장 섀시"
 ],
 "Failed": [
  null,
  "실패하였습니다"
 ],
 "Failed to change firmware": [
  null,
  "펌웨어 변경에 실패하였습니다"
 ],
 "Failed to change password": [
  null,
  "비밀번호 변경 실패"
 ],
 "Failed to clone VM $0": [
  null,
  "VM $0 복제에 실패하였습니다"
 ],
 "Failed to fetch the IP addresses of the interfaces present in $0": [
  null,
  "$0에 표시된 연결장치의 IP 주소를 가져오지 못했습니다"
 ],
 "Failed to send key Ctrl+Alt+$0 to VM $1": [
  null,
  "키 Ctrl+Alt+$0를 VM $1으로 보내지 못했습니다"
 ],
 "Fewer than the maximum number of virtual CPUs should be enabled.": [
  null,
  "최대 가상 CPU 수 보다 적은 수를 활성화해야 합니다."
 ],
 "File": [
  null,
  "파일"
 ],
 "Filesystem directory": [
  null,
  "파일 시스템 디렉토리"
 ],
 "Filter by name": [
  null,
  "이름으로 필터링"
 ],
 "Firmware": [
  null,
  "펌웨어"
 ],
 "Force reboot": [
  null,
  "강제 재시작"
 ],
 "Force shut down": [
  null,
  "강제 종료"
 ],
 "Format": [
  null,
  "포멧"
 ],
 "Forward mode": [
  null,
  "포워드 모드"
 ],
 "Forwarding mode": [
  null,
  "포워딩 방법"
 ],
 "General": [
  null,
  "일반"
 ],
 "Generate automatically": [
  null,
  "자동 생성"
 ],
 "GiB": [
  null,
  "GiB"
 ],
 "Go to VMs list": [
  null,
  "VM 목록으로 이동"
 ],
 "Go to now": [
  null,
  "지금 바로 가기"
 ],
 "Handheld": [
  null,
  "휴대용"
 ],
 "Hide additional options": [
  null,
  "추가 선택 숨기기"
 ],
 "Host": [
  null,
  "호스트"
 ],
 "Host device": [
  null,
  "호스트 장치"
 ],
 "Host name": [
  null,
  "호스트 이름"
 ],
 "Host should not be empty": [
  null,
  "호스트는 비워둘 수 없습니다"
 ],
 "Hours must be a number between 0 and 23": [
  null,
  "시간은 0에서 23 사이의 숫자 여야합니다"
 ],
 "Hypervisor details": [
  null,
  "하이퍼바이저 세부 사항"
 ],
 "ID": [
  null,
  "ID"
 ],
 "IP address": [
  null,
  "IP 주소"
 ],
 "IP configuration": [
  null,
  "IP 구성"
 ],
 "IPv4 address": [
  null,
  "IPv4 주소"
 ],
 "IPv4 and IPv6": [
  null,
  "IPv4 및 IPv6"
 ],
 "IPv4 network": [
  null,
  "IPv4 네트워크"
 ],
 "IPv4 network should not be empty": [
  null,
  "IPv4 네트워크는 비워둘 수 없습니다"
 ],
 "IPv4 only": [
  null,
  "IPv4만"
 ],
 "IPv6 address": [
  null,
  "IPv6 주소"
 ],
 "IPv6 network": [
  null,
  "IPv6 네트워크"
 ],
 "IPv6 network should not be empty": [
  null,
  "IPv6 네트워크는 비워둘 수 없습니다"
 ],
 "IPv6 only": [
  null,
  "IPv6만"
 ],
 "Idle": [
  null,
  "유휴"
 ],
 "Immediately start VM": [
  null,
  "바로 VM을 시작"
 ],
 "Import": [
  null,
  "가져오기"
 ],
 "Import VM": [
  null,
  "VM 가져 오기"
 ],
 "Import a virtual machine": [
  null,
  "가상 머신 가져 오기"
 ],
 "In most configurations, macvtap does not work for host to guest network communication.": [
  null,
  "대부분의 설정에서 macvtap는 호스트와 게스트 간 네트워크 통신에서 작동하지 않습니다."
 ],
 "Initiator": [
  null,
  "초기자"
 ],
 "Initiator IQN should not be empty": [
  null,
  "초기자 IQN은 비워둘 수 없습니다"
 ],
 "Install": [
  null,
  "설치"
 ],
 "Install software": [
  null,
  "소프트웨어 설치"
 ],
 "Installation source": [
  null,
  "설치 소스"
 ],
 "Installation source must not be empty": [
  null,
  "설치 소스는 비워둘 수 없습니다"
 ],
 "Installation type": [
  null,
  "설치 유형"
 ],
 "Installing $0": [
  null,
  "$0 설치 중"
 ],
 "Interface type": [
  null,
  "연결장치 유형"
 ],
 "Invalid IPv4 address": [
  null,
  "잘못된 IPv4 주소"
 ],
 "Invalid IPv4 mask or prefix length": [
  null,
  "잘못된 IPv4 매스크 또는 프리픽스 길이"
 ],
 "Invalid IPv6 address": [
  null,
  "잘못된 IPv6 주소"
 ],
 "Invalid IPv6 prefix": [
  null,
  "잘못된 IPv6 프리픽스"
 ],
 "Invalid date format": [
  null,
  "잘못된 날짜 형식"
 ],
 "Invalid date format and invalid time format": [
  null,
  "잘못된 날짜 형식 및 잘못된 시간 형식"
 ],
 "Invalid file permissions": [
  null,
  "잘못된 파일 권한"
 ],
 "Invalid filename": [
  null,
  "잘못된 파일 이름"
 ],
 "Invalid time format": [
  null,
  "잘못된 시간 형식"
 ],
 "Invalid timezone": [
  null,
  "잘못된 시간대"
 ],
 "IoT gateway": [
  null,
  "IoT 게이트웨이"
 ],
 "Isolated network": [
  null,
  "격리된 네트워크"
 ],
 "LVM volume group": [
  null,
  "LVM 볼륨 그룹"
 ],
 "Laptop": [
  null,
  "랩탑"
 ],
 "Launch remote viewer": [
  null,
  "원격 뷰어 시작"
 ],
 "Learn more": [
  null,
  "더 알아보기"
 ],
 "Leave the password blank if you do not wish to have a root account created": [
  null,
  "root 계정을 만들지 않으려면 암호를 비워 두십시오"
 ],
 "Leave the password blank if you do not wish to have a user account created": [
  null,
  "사용자 계정을 만들지 않으려면 암호를 비워 두십시오"
 ],
 "Leave the password blank if you do not wish to set a root password": [
  null,
  "root 비밀번호를 설정하기를 원하지 않으면 비밀번호를 비워 두십시오"
 ],
 "Libvirt did not detect any UEFI/OVMF firmware image installed on the host": [
  null,
  "Libvirt가 호스트에 설치된 UEFI/OVMF 펌웨어 이미지를 감지하지 못했습니다"
 ],
 "Libvirt or hypervisor does not support UEFI": [
  null,
  "Libvirt 또는 하이퍼바이저는 UEFI를 지원하지 않습니다"
 ],
 "Loading resources": [
  null,
  "자원 적재 중"
 ],
 "Loading system modifications...": [
  null,
  "시스템 수정 로딩 중..."
 ],
 "Loading...": [
  null,
  "적재 중..."
 ],
 "Local install media (ISO image or distro install tree)": [
  null,
  "로컬 설치 미디어 (ISO 이미지 또는 저장소 설치 트리)"
 ],
 "Log messages": [
  null,
  "로그 메세지"
 ],
 "Low profile desktop": [
  null,
  "낮은 프로파일 데스크탑"
 ],
 "Lunch box": [
  null,
  "Lunch Box"
 ],
 "MAC": [
  null,
  "MAC"
 ],
 "MAC address": [
  null,
  "MAC 주소"
 ],
 "Machine must be shut off before changing bus type": [
  null,
  "버스 유형을 변경하기 전에 장치를 종료해야 합니다"
 ],
 "Machine must be shut off before changing cache mode": [
  null,
  "캐쉬 방법을 변경하기 전에 장치를 종료해야 합니다"
 ],
 "Main server chassis": [
  null,
  "메인 서버 섀시"
 ],
 "Managing virtual machines": [
  null,
  "가상 머신 관리"
 ],
 "Manual connection": [
  null,
  "수동 연결"
 ],
 "Manually": [
  null,
  "수동"
 ],
 "Mask or prefix length": [
  null,
  "매스크 또는프리픽스 길이"
 ],
 "Mask or prefix length should not be empty": [
  null,
  "매스크 또는 프리픽스 길이는 비워둘 수 없습니다"
 ],
 "Maximum allocation": [
  null,
  "최대 할당"
 ],
 "Maximum memory could not be saved": [
  null,
  "최대 메모리는 저장 할 수 없습니다"
 ],
 "Maximum number of virtual CPUs allocated for the guest OS": [
  null,
  "게스트 OS에 할당된 가상 CPU의 최대 개수"
 ],
 "Maximum number of virtual CPUs allocated for the guest OS, which must be between 1 and $0": [
  null,
  "게스트 OS에 할당된 가상 CPU의 최대 개수는 1에서 $0 사이여야 합니다"
 ],
 "Maximum transmission unit": [
  null,
  "MTU(Maximum Transmission Unit)"
 ],
 "Memory": [
  null,
  "메모리"
 ],
 "Memory could not be saved": [
  null,
  "메모리를 저장 할 수 없습니다"
 ],
 "Memory must not be 0": [
  null,
  "메모리는 0이 아니어야 합니다"
 ],
 "Message to logged in users": [
  null,
  "로그인한 사용자에게 보내는 메세지"
 ],
 "MiB": [
  null,
  "MiB"
 ],
 "Mini PC": [
  null,
  "미니 PC"
 ],
 "Mini tower": [
  null,
  "미니 타워"
 ],
 "Minutes must be a number between 0 and 59": [
  null,
  "분은 0에서 59 사이의 숫자이어야합니다"
 ],
 "Mode": [
  null,
  "모드"
 ],
 "Model": [
  null,
  "방식"
 ],
 "Model type": [
  null,
  "모델 유형"
 ],
 "Multi-system chassis": [
  null,
  "멀티 시스템 섀시"
 ],
 "NAT to $0": [
  null,
  "$0에 NAT"
 ],
 "NIC $0 of VM $1 failed to change state": [
  null,
  "VM $1의 NIC $0은 상태 변경에 실패했습니다"
 ],
 "NTP server": [
  null,
  "NTP 서버"
 ],
 "Name": [
  null,
  "이름"
 ],
 "Name contains invalid characters": [
  null,
  "이름에 잘못된 문자가 있습니다"
 ],
 "Name must not be empty": [
  null,
  "이름을 입력하셔야 합니다"
 ],
 "Name should not be empty": [
  null,
  "이름을 입력해야 합니다"
 ],
 "Name: ": [
  null,
  "이름: "
 ],
 "Need at least one NTP server": [
  null,
  "최소 하나의 NTP 서버가 필요합니다"
 ],
 "Netmask": [
  null,
  "넷마스크"
 ],
 "Network $0 failed to get activated": [
  null,
  "네트워크 $0의 활성화에 실패했습니다"
 ],
 "Network $0 failed to get deactivated": [
  null,
  "네트워크 $0의 비활성화에 실패했습니다"
 ],
 "Network boot (PXE)": [
  null,
  "네트워크 부팅(PXE)"
 ],
 "Network file system": [
  null,
  "네트워크 파일 시스템"
 ],
 "Network interface settings could not be saved": [
  null,
  "네트워크 연결장치 설정을 저장하지 못했습니다"
 ],
 "Network selection does not support PXE.": [
  null,
  "네트워크 선택은 PXE를 지원하지 않습니다."
 ],
 "Networks": [
  null,
  "네트워크"
 ],
 "New password was not accepted": [
  null,
  "새 비밀번호가 허용되지 않습니다"
 ],
 "New volume name": [
  null,
  "새 볼륨 이름"
 ],
 "No VM is running or defined on this host": [
  null,
  "이 호스트에서 실행 중이거나 정의된 가상 머신이 없습니다"
 ],
 "No boot device found": [
  null,
  "부팅 장치를 찾을 수 없습니다"
 ],
 "No connection available": [
  null,
  "사용 가능한 연결 없음"
 ],
 "No delay": [
  null,
  "지연 없음"
 ],
 "No description": [
  null,
  "설명 없음"
 ],
 "No disks defined for this VM": [
  null,
  "이 가상 머신에 지정된 디스크가 없습니다"
 ],
 "No network devices": [
  null,
  "네트워크 장치 없음"
 ],
 "No network interfaces defined for this VM": [
  null,
  "이 가상 머신에 네트워크 연결장치가 정의되지 않았습니다"
 ],
 "No network is defined on this host": [
  null,
  "이 호스트에 정의된 네트워크가 없습니다"
 ],
 "No networks available": [
  null,
  "사용 가능한 네트워크가 없습니다"
 ],
 "No parent": [
  null,
  "원인 개체 없음"
 ],
 "No snapshots defined for this VM": [
  null,
  "이 VM에 대해 정의된 스냅샷 없음"
 ],
 "No state": [
  null,
  "상태 없음"
 ],
 "No storage": [
  null,
  "저장소 없음"
 ],
 "No storage pool is defined on this host": [
  null,
  "이 호스트에 지정된 저장소 풀이 없습니다"
 ],
 "No storage pools available": [
  null,
  "사용 가능한 저장소 풀 없음"
 ],
 "No storage volumes defined for this storage pool": [
  null,
  "이 저장소 풀에 대해 정의된 저장소 볼륨 없음"
 ],
 "No such file or directory": [
  null,
  "이러한 파일 또는 디렉토리가 없습니다"
 ],
 "No system modifications": [
  null,
  "시스템 수정 없음"
 ],
 "No virtual networks": [
  null,
  "가상 네트워크 없음"
 ],
 "Non-persistent network cannot be deleted. It ceases to exists when it's deactivated.": [
  null,
  "비영구적 네트워크는 삭제할 수 없습니다. 비활성화되면 존재하지 않습니다."
 ],
 "Non-persistent storage pool cannot be deleted. It ceases to exists when it's deactivated.": [
  null,
  "비영구적 저장소 풀은 삭제할 수 없습니다. 비활성화되면 존재하지 않습니다."
 ],
 "None": [
  null,
  "없음"
 ],
 "None (isolated network)": [
  null,
  "없음(격리된 네트워크)"
 ],
 "Not a valid private key": [
  null,
  "유효한 개인 키가 없습니다"
 ],
 "Not synchronized": [
  null,
  "동기화되어 있지 않습니다"
 ],
 "Notebook": [
  null,
  "노트북"
 ],
 "Ok": [
  null,
  "확인"
 ],
 "Old password not accepted": [
  null,
  "이전 비밀번호가 허용되지 않습니다"
 ],
 "One or more selected volumes are used by domains. Detach the disks first to allow volume deletion.": [
  null,
  "하나 이상의 선택된 볼륨이 도메인에서 사용되고 있습니다. 먼저 디스크를 분리하여 볼륨을 삭제하십시오."
 ],
 "Only editable when the guest is shut off": [
  null,
  "게스트가 종료된 경우에만 편집할 수 있습니다"
 ],
 "Open": [
  null,
  "열기"
 ],
 "Operating system": [
  null,
  "운영 체제"
 ],
 "Operation is in progress": [
  null,
  "실행 중인 작업"
 ],
 "Other": [
  null,
  "기타"
 ],
 "Overview": [
  null,
  "개요"
 ],
 "PackageKit crashed": [
  null,
  "PackageKit가 충돌했습니다"
 ],
 "Parent snapshot": [
  null,
  "원인 스냅샷"
 ],
 "Password is not acceptable": [
  null,
  "비밀번호가 허용되지 않습니다"
 ],
 "Password is too weak": [
  null,
  "암호가 너무 취약합니다"
 ],
 "Password not accepted": [
  null,
  "비밀번호가 허용되지 않습니다"
 ],
 "Paste": [
  null,
  "붙여넣기"
 ],
 "Path": [
  null,
  "경로"
 ],
 "Path on host's filesystem": [
  null,
  "호스트 파일시스템의 경로"
 ],
 "Path to ISO file on host's file system": [
  null,
  "호스트의 파일 시스템에서 ISO 파일로의 경로"
 ],
 "Path to cloud image file on host's file system": [
  null,
  "호스트 파일 시스템에서 클라우드 이미지 파일 경로"
 ],
 "Path to file": [
  null,
  "파일의 경로"
 ],
 "Path to file on host's file system": [
  null,
  "호스트 파일 시스템에서 파일의 경로"
 ],
 "Pause": [
  null,
  "일시정지"
 ],
 "Paused": [
  null,
  "일시정지"
 ],
 "Peripheral chassis": [
  null,
  "주변 장치 섀시"
 ],
 "Persistence": [
  null,
  "고집"
 ],
 "Persistent": [
  null,
  "지속적"
 ],
 "Physical disk device": [
  null,
  "물리적 디스크 장치"
 ],
 "Physical disk device on host": [
  null,
  "호스트에서 물리적 디스크 장치"
 ],
 "Pick date": [
  null,
  "날짜 선택"
 ],
 "Pizza box": [
  null,
  "피자 박스"
 ],
 "Please choose a storage pool": [
  null,
  "저장소 풀을 선택하십시오"
 ],
 "Please choose a volume": [
  null,
  "볼륨을 선택하십시오"
 ],
 "Please enter new volume name": [
  null,
  "새 볼륨 이름을 입력해 주십시오"
 ],
 "Please start the virtual machine to access its console.": [
  null,
  "가상 머신을 시작하여 콘솔에 액세스하십시오."
 ],
 "Plug": [
  null,
  "플러그"
 ],
 "Pool": [
  null,
  "풀"
 ],
 "Pool needs to be active to create volume": [
  null,
  "볼륨 생성을 위해 풀을 활성화해야 합니다"
 ],
 "Pool type doesn't support volume creation": [
  null,
  "풀 유형이 볼륨 생성을 지원하지 않습니다"
 ],
 "Pool's volumes are used by VMs ": [
  null,
  "풀 볼륨은 VM에서 사용됩니다 "
 ],
 "Port": [
  null,
  "포트"
 ],
 "Portable": [
  null,
  "이동식"
 ],
 "Preferred number of sockets to expose to the guest.": [
  null,
  "게스트에게 공개하기 위한 권장 소캣 수입니다."
 ],
 "Prefix": [
  null,
  "접두어"
 ],
 "Prefix length": [
  null,
  "접두 길이"
 ],
 "Prefix length should not be empty": [
  null,
  "프리픽스 길이는 비워둘 수 없습니다"
 ],
 "Present": [
  null,
  "존재"
 ],
 "Previously taken snapshots allow you to revert to an earlier state if something goes wrong": [
  null,
  "이전에 촬영한 스냅샷을 사용하면 문제가 발생했을 때 이전 상태로 돌아갈 수 있습니다"
 ],
 "Private": [
  null,
  "비공개"
 ],
 "Product": [
  null,
  "제품"
 ],
 "Profile": [
  null,
  "프로파일"
 ],
 "Prompting via ssh-add timed out": [
  null,
  "ssh-add를 통한 메세지 제공 시간이 초과되었습니다"
 ],
 "Prompting via ssh-keygen timed out": [
  null,
  "ssh-keygen을 통한 메세지 제공시간이 초과되었습니다"
 ],
 "Protocol": [
  null,
  "프로토콜"
 ],
 "RAID chassis": [
  null,
  "RAID 섀시"
 ],
 "Rack mount chassis": [
  null,
  "랙 마운트 섀시"
 ],
 "Read-only": [
  null,
  "읽기 전용"
 ],
 "Reboot": [
  null,
  "재시작"
 ],
 "Remote URL": [
  null,
  "원격 URL"
 ],
 "Remote viewer details": [
  null,
  "원격 뷰어 세부 정보"
 ],
 "Removals:": [
  null,
  "삭제:"
 ],
 "Remove": [
  null,
  "제거"
 ],
 "Removing $0": [
  null,
  "$0 삭제 중"
 ],
 "Resume": [
  null,
  "다시 시작"
 ],
 "Revert": [
  null,
  "되돌리기"
 ],
 "Revert to snapshot $0": [
  null,
  "스냅샷 $0(으)로 되돌리기"
 ],
 "Reverting to this snapshot will take the VM back to the time of the snapshot and the current state will be lost, along with any data not captured in a snapshot": [
  null,
  "이 스냅샷으로 되돌리면 VM이 스냅샷 촬영 시점으로 돌아가며 스냅샷에 캡처되지 않은 데이터와 함께 현재 상태가 모두 손실됩니다"
 ],
 "Root password": [
  null,
  "root 암호"
 ],
 "Route to $0": [
  null,
  "$0로 라우팅"
 ],
 "Routed network": [
  null,
  "라우팅된 네트워크"
 ],
 "Run": [
  null,
  "실행"
 ],
 "Run unattended installation": [
  null,
  "무인 설치 실행"
 ],
 "Run when host boots": [
  null,
  "호스트 부팅 시 실행"
 ],
 "Running": [
  null,
  "작동중"
 ],
 "SPICE TLS port": [
  null,
  "SPICE TLS 포트"
 ],
 "SPICE address": [
  null,
  "SPICE 주소"
 ],
 "SPICE port": [
  null,
  "SPICE 포트"
 ],
 "Save": [
  null,
  "저장"
 ],
 "Sealed-case PC": [
  null,
  "쉴드 케이스 PC"
 ],
 "Select console type": [
  null,
  "콘솔 유형 선택"
 ],
 "Send key": [
  null,
  "키 전송"
 ],
 "Send non-maskable interrupt": [
  null,
  "마스크 불가능 인터럽트 보내기"
 ],
 "Serial console": [
  null,
  "직렬 콘솔"
 ],
 "Session": [
  null,
  "세션"
 ],
 "Set DHCP range": [
  null,
  "DHCP 범위 설정"
 ],
 "Set manually": [
  null,
  "수동 설정"
 ],
 "Set time": [
  null,
  "시간 설정"
 ],
 "Setting the user passwords for unattended installation requires starting the VM when creating it": [
  null,
  "자동 설치를 위한 사용자 암호를 설정하려면 VM을 생성할 때 VM을 시작해야합니다"
 ],
 "Shell script": [
  null,
  "쉘 스크립트"
 ],
 "Shift+Insert": [
  null,
  "Shift+Insert"
 ],
 "Show additional options": [
  null,
  "추가 옵션 표시"
 ],
 "Shut down": [
  null,
  "종료"
 ],
 "Shut off": [
  null,
  "종료"
 ],
 "Shut off the VM in order to edit firmware configuration": [
  null,
  "펌웨어 구성을 편집하려면 VM을 종료하십시오"
 ],
 "Shutting down": [
  null,
  "종료 중"
 ],
 "Single rank": [
  null,
  "단일 등급"
 ],
 "Size": [
  null,
  "크기"
 ],
 "Snapshot failed to be created": [
  null,
  "스냅샷을 만들지 못했습니다"
 ],
 "Snapshots": [
  null,
  "스냅샷"
 ],
 "Sockets": [
  null,
  "소켓"
 ],
 "Source": [
  null,
  "소스"
 ],
 "Source format": [
  null,
  "소스 형식"
 ],
 "Source path": [
  null,
  "소스 경로"
 ],
 "Source path should not be empty": [
  null,
  "소스 경로를 비워둘 수 없습니다"
 ],
 "Source should start with http, ftp or nfs protocol": [
  null,
  "소스는 http, ftp, nfs 프로토콜로 시작해야 합니다"
 ],
 "Source volume group": [
  null,
  "소스 볼륨 그룹"
 ],
 "Space-saving computer": [
  null,
  "공간 절약형 컴퓨터"
 ],
 "Specific time": [
  null,
  "특정 시간"
 ],
 "Start": [
  null,
  "시작"
 ],
 "Start libvirt": [
  null,
  "libvirt 시작"
 ],
 "Start pool when host boots": [
  null,
  "호스트 부팅 시 풀 시작"
 ],
 "Start should not be empty": [
  null,
  "시작은 비워둘 수 없습니다"
 ],
 "Startup": [
  null,
  "시작"
 ],
 "State": [
  null,
  "상태"
 ],
 "Stick PC": [
  null,
  "스틱 PC"
 ],
 "Storage": [
  null,
  "저장소"
 ],
 "Storage pool $0 failed to get activated": [
  null,
  "저장소 풀 $0의 활성화에 실패했습니다"
 ],
 "Storage pool $0 failed to get deactivated": [
  null,
  "저장소 풀 $0의 비활성화에 실패했습니다"
 ],
 "Storage pool failed to be created": [
  null,
  "저장소 풀 생성에 실패했습니다"
 ],
 "Storage pool name": [
  null,
  "저장소 풀 이름"
 ],
 "Storage pools": [
  null,
  "저장장치 풀"
 ],
 "Storage size must not be 0": [
  null,
  "저장소 크기가 0이 되어서는 안됩니다"
 ],
 "Storage volume": [
  null,
  "저장소 볼륨"
 ],
 "Storage volume size must not exceed the storage pool's capacity ($0 $1)": [
  null,
  "저장소 볼륨 크기는 저장소 풀의 용량을 초과해서는 안 됩니다($0 $1)"
 ],
 "Storage volumes": [
  null,
  "저장소 볼륨"
 ],
 "Storage volumes could not be deleted": [
  null,
  "저장소 볼륨은 삭제 할 수 없습니다"
 ],
 "Sub-Chassis": [
  null,
  "서브 섀시"
 ],
 "Sub-Notebook": [
  null,
  "서브 노트북"
 ],
 "Suspended (PM)": [
  null,
  "일시 정지됩니다(PM)"
 ],
 "Synchronized": [
  null,
  "동기화됩니다"
 ],
 "Synchronized with $0": [
  null,
  "$0와 동기화됩니다"
 ],
 "Synchronizing": [
  null,
  "동기화 중"
 ],
 "System": [
  null,
  "시스템"
 ],
 "Tablet": [
  null,
  "타블렛"
 ],
 "Target": [
  null,
  "대상"
 ],
 "Target path": [
  null,
  "대상 경로"
 ],
 "Target path should not be empty": [
  null,
  "대상 경로를 비워둘 수 없습니다"
 ],
 "The $0 could not be deleted": [
  null,
  "$0을(를) 삭제할 수 없습니다"
 ],
 "The VM is running and will be forced off before deletion.": [
  null,
  "가상 머신이 실행되고 있으므로 삭제 전 강제로 종료됩니다."
 ],
 "The VM needs to be running or shut off to detach this device": [
  null,
  "이 장치를 분리하려면 VM이 실행 중이거나 종료되어 있어야합니다"
 ],
 "The directory on the server being exported": [
  null,
  "서버의 디렉토리를 내보내는 중"
 ],
 "The logged in user is not permitted to view system modifications": [
  null,
  "로그인한 사용자는 시스템 수정 사항을 볼 수 없습니다"
 ],
 "The passwords do not match.": [
  null,
  "암호가 일치하지 않습니다."
 ],
 "The pool is empty": [
  null,
  "풀이 비어 있습니다"
 ],
 "The selected operating system does not support unattended installation": [
  null,
  "선택한 운영 체제가 자동 설치를 지원하지 않습니다"
 ],
 "The selected operating system has minimum memory requirement of $0 $1": [
  null,
  "선택한 운영 체제의 최소 메모리 요구 사항은 $0 $1입니다"
 ],
 "The selected operating system has minimum storage size requirement of $0 $1": [
  null,
  "선택한 운영 체제의 최소 저장소 크기 요구 사항은 $0 $1입니다"
 ],
 "The storage pool could not be deleted": [
  null,
  "저장소 풀을 삭제 할 수 없습니다"
 ],
 "This VM is transient. Shut it down if you wish to delete it.": [
  null,
  "이 VM은 일시적입니다. 삭제하려면 VM을 종료하십시오."
 ],
 "This volume is already used by another VM.": [
  null,
  "이 볼륨은 이미 다른 가상 머신에서 사용하고 있습니다."
 ],
 "This volume is already used by: ": [
  null,
  "이 볼륨은 다음에서 이미 사용하고 있습니다. "
 ],
 "Threads per core": [
  null,
  "코어 당 스레드"
 ],
 "Time zone": [
  null,
  "시간대"
 ],
 "Today": [
  null,
  "오늘"
 ],
 "Total size: $0": [
  null,
  "전체 크기: $0"
 ],
 "Tower": [
  null,
  "타워"
 ],
 "Transient VMs don't support editing firmware configuration": [
  null,
  "Transient VM은 펌웨어 구성 편집을 지원하지 않습니다"
 ],
 "Troubleshoot": [
  null,
  "문제 해결"
 ],
 "Trying to synchronize with $0": [
  null,
  "$0와 동기화를 시도 중입니다"
 ],
 "Type": [
  null,
  "유형"
 ],
 "Type ID": [
  null,
  "ID 입력"
 ],
 "URL (ISO image or distro install tree)": [
  null,
  "URL (ISO 이미지 또는 저장소 설치 트리)"
 ],
 "Unique name": [
  null,
  "고유한 이름"
 ],
 "Unique network name": [
  null,
  "고유한 네트워크 이름"
 ],
 "Unit": [
  null,
  "단위"
 ],
 "Unknown": [
  null,
  "알 수 없음"
 ],
 "Unknown firmware": [
  null,
  "알 수 없는 펌웨어"
 ],
 "Unplug": [
  null,
  "언플러그"
 ],
 "Up to $0 $1 available on the default location": [
  null,
  "지정된 장소에서 최대 $0 $1 사용 가능"
 ],
 "Up to $0 $1 available on the host": [
  null,
  "호스트에서 최대 $0 $1 사용 가능"
 ],
 "Url": [
  null,
  "URL"
 ],
 "Usage": [
  null,
  "사용량"
 ],
 "Use existing": [
  null,
  "기존 사용"
 ],
 "Used": [
  null,
  "사용 중"
 ],
 "Used by": [
  null,
  "사용되었습니다"
 ],
 "User login": [
  null,
  "사용자 로그인"
 ],
 "User login must not be empty when user password is set": [
  null,
  "사용자 로그인은 사용자 비밀번호 설정 할 때에 비워두지 않아야 합니다"
 ],
 "User password": [
  null,
  "암호 사용"
 ],
 "User password must not be empty when user login is set": [
  null,
  "사용자 비밀번호는 사용자 로그인 설정 할 때에 비워두지 않아야 합니다"
 ],
 "VCPU settings could not be saved": [
  null,
  "VCPU 설정을 저장할 수 없습니다"
 ],
 "VM $0 already exists": [
  null,
  "VM $0이 이미 존재합니다"
 ],
 "VM $0 does not exist on $1 connection": [
  null,
  "VM $0이(가) $1 연결에 존재하지 않습니다"
 ],
 "VM $0 failed to force reboot": [
  null,
  "VM $0의 강제 재시작에 실패했습니다"
 ],
 "VM $0 failed to force shutdown": [
  null,
  "VM $0 강제 종료에 실패했습니다"
 ],
 "VM $0 failed to get deleted": [
  null,
  "VM $0 삭제에 실패했습니다"
 ],
 "VM $0 failed to get installed": [
  null,
  "VM $0 설치에 실패했습니다"
 ],
 "VM $0 failed to pause": [
  null,
  "VM $0 일시 정지에 실패했습니다"
 ],
 "VM $0 failed to reboot": [
  null,
  "VM $0의 재시작에 실패했습니다"
 ],
 "VM $0 failed to resume": [
  null,
  "VM $0 재개에 실패했습니다"
 ],
 "VM $0 failed to send NMI": [
  null,
  "VM $0의 NMI 전송에 실패했습니다"
 ],
 "VM $0 failed to shutdown": [
  null,
  "VM $0 종료에 실패했습니다"
 ],
 "VM $0 failed to start": [
  null,
  "VM $0 시작에 실패했습니다"
 ],
 "VM state": [
  null,
  "VM 상태"
 ],
 "VNC TLS port": [
  null,
  "VNC TLS 포트"
 ],
 "VNC address": [
  null,
  "VNC 주소"
 ],
 "VNC console": [
  null,
  "VNC 콘솔"
 ],
 "VNC port": [
  null,
  "VNC 포트"
 ],
 "Vendor": [
  null,
  "제조사"
 ],
 "View automation script": [
  null,
  "자동 스크립트 보기"
 ],
 "Virtual Machines": [
  null,
  "가상머신"
 ],
 "Virtual machines": [
  null,
  "가상 머신"
 ],
 "Virtual machines management": [
  null,
  "가상 머신 관리"
 ],
 "Virtual network": [
  null,
  "가상 네트워크"
 ],
 "Virtual network failed to be created": [
  null,
  "가상 네트워크를 만들지 못했습니다"
 ],
 "Virtualization service (libvirt) is not active": [
  null,
  "가상화 서비스(libvirt)가 활성화되어 있지 않습니다"
 ],
 "Volume": [
  null,
  "볼륨"
 ],
 "Volume failed to be created": [
  null,
  "볼륨을 만들지 못했습니다"
 ],
 "Volume group name": [
  null,
  "볼륨 그룹 이름"
 ],
 "Volume group name should not be empty": [
  null,
  "볼륨 그룹 이름은 비워둘 수 없습니다"
 ],
 "WWPN": [
  null,
  "WWPN"
 ],
 "Waiting for other software management operations to finish": [
  null,
  "다른 소프트웨어 관리 작업이 완료될 때 까지 대기 중"
 ],
 "Writeable": [
  null,
  "쓰기 가능"
 ],
 "Writeable and shared": [
  null,
  "쓰기 가능 및 공유"
 ],
 "Yesterday": [
  null,
  "어제"
 ],
 "You need to select the most closely matching operating system": [
  null,
  "가장 일치하는 운영 체제를 선택해야합니다"
 ],
 "[$0 bytes of binary data]": [
  null,
  "[바이너리 데이터의 $0 바이트]"
 ],
 "[binary data]": [
  null,
  "[바이너리 데이터]"
 ],
 "[no data]": [
  null,
  "[데이터 없음]"
 ],
 "active": [
  null,
  "활성"
 ],
 "bridge": [
  null,
  "브릿지"
 ],
 "cdrom": [
  null,
  "cdrom"
 ],
 "custom": [
  null,
  "사용자 지정"
 ],
 "direct": [
  null,
  "직접"
 ],
 "disabled": [
  null,
  "비활성화됩니다"
 ],
 "disk": [
  null,
  "디스크"
 ],
 "down": [
  null,
  "아래로"
 ],
 "edit": [
  null,
  "편집"
 ],
 "enabled": [
  null,
  "활성화됩니다"
 ],
 "ethernet": [
  null,
  "이더넷"
 ],
 "host": [
  null,
  "호스트"
 ],
 "host device": [
  null,
  "호스트 장치"
 ],
 "host passthrough": [
  null,
  "호스트 통과"
 ],
 "hostdev": [
  null,
  "hostdev"
 ],
 "iSCSI direct target": [
  null,
  "iSCSI 직접 대상"
 ],
 "iSCSI initiator IQN": [
  null,
  "iSCSI 개시자 IQN"
 ],
 "iSCSI target": [
  null,
  "iSCSI 대상"
 ],
 "iSCSI target IQN": [
  null,
  "iSCSI 대상 IQN"
 ],
 "iso": [
  null,
  "iso"
 ],
 "libvirt": [
  null,
  "libvirt"
 ],
 "mcast": [
  null,
  "mcast"
 ],
 "network": [
  null,
  "네트워크"
 ],
 "no": [
  null,
  "아니요"
 ],
 "no state saved": [
  null,
  "저장된 상태 없음"
 ],
 "password quality": [
  null,
  "비밀번호 수준"
 ],
 "pxe": [
  null,
  "pxe"
 ],
 "qcow2": [
  null,
  "qcow2"
 ],
 "qemu": [
  null,
  "qemu"
 ],
 "redirected device": [
  null,
  "리디렉트된 장치"
 ],
 "server": [
  null,
  "서버"
 ],
 "show less": [
  null,
  "덜 보기"
 ],
 "show more": [
  null,
  "더 보기"
 ],
 "udp": [
  null,
  "udp"
 ],
 "up": [
  null,
  "위로"
 ],
 "user": [
  null,
  "사용자"
 ],
 "vCPU count": [
  null,
  "vCPU 개수"
 ],
 "vCPU maximum": [
  null,
  "vCPU 최대"
 ],
 "vCPUs": [
  null,
  "vCPU"
 ],
 "vhostuser": [
  null,
  "vhostuser"
 ],
 "view more...": [
  null,
  "더 알아보기..."
 ],
 "virt-install package needs to be installed on the system in order to clone VMs": [
  null,
  "VM을 복제하려면 시스템에 virt-install 꾸러미를 설치해야 합니다"
 ],
 "virt-install package needs to be installed on the system in order to create new VMs": [
  null,
  "새로운 가상 머신을 생성하려면 시스템에 virt-install 꾸러미를 설치해야 합니다"
 ],
 "virt-install package needs to be installed on the system in order to edit this attribute": [
  null,
  "이 속성을 편집하려면 시스템에 virt-install 꾸러미를 설치해야 합니다"
 ],
 "vm": [
  null,
  "vm"
 ],
 "yes": [
  null,
  "예"
 ]
});
